"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.attachmentFields = exports.attachmentOperations = void 0;
exports.attachmentOperations = [
    {
        displayName: 'Operation',
        name: 'operation',
        type: 'options',
        noDataExpression: true,
        displayOptions: {
            show: {
                resource: ['attachment'],
            },
        },
        options: [
            {
                name: 'Create',
                value: 'create',
                description: 'Create an attachment',
                action: 'Create an attachment',
                routing: {
                    request: {
                        baseURL: 'https://test.automaton.ninja/anything',
                        method: 'POST',
                        url: '/Attachment',
                        headers: {
                            Accept: 'application/json',
                            'Content-Type': 'multipart/form-data',
                        },
                    },
                },
            },
        ],
        default: 'create',
    },
];
const createOperation = [
    {
        displayName: 'Send Custom Fields',
        name: 'attachmentFields',
        type: 'boolean',
        displayOptions: {
            show: {
                resource: ['attachment'],
                operation: ['create'],
            },
        },
        default: true,
        description: 'Whether creating object requires more attachment prameters',
    },
    {
        displayName: 'Custom Fields',
        name: 'attachmentProperties',
        type: 'fixedCollection',
        displayOptions: {
            show: {
                resource: ['attachment'],
                operation: ['create'],
                attachmentFields: [true],
            },
        },
        default: {
            property: [
                {
                    name: '',
                    value: '',
                },
            ],
        },
        placeholder: 'Add Custom Field',
        typeOptions: {
            multipleValues: true,
        },
        options: [
            {
                name: 'property',
                displayName: 'Custom Field',
                values: [
                    {
                        displayName: 'Field Name or ID',
                        name: 'name',
                        type: 'string',
                        required: true,
                        default: '',
                        description: 'Name of the attachment field to set',
                    },
                    {
                        displayName: 'Field Value',
                        name: 'value',
                        type: 'string',
                        required: true,
                        default: '',
                        routing: {
                            send: {
                                type: 'body',
                                propertyInDotNotation: true,
                                property: '=FormData.{{$parent.name}}',
                                value: '={{ $value !== " " ? $value : undefined }}',
                            },
                            request: {
                                headers: {
                                    'Content-Disposition': 'form-data',
                                    'name': "part1.json",
                                },
                            },
                        },
                        description: 'Value to set on the attachment field',
                    },
                ],
            },
        ],
    },
];
const deleteOperation = [
    {
        displayName: 'Record ID',
        name: 'id',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                operation: ['delete'],
                resource: ['attachment'],
            },
        },
        routing: {
            request: {
                url: "=/{{$parameter['busenessObjectId']}}s('{{ $value }}')",
            },
        },
        description: 'RecId value of the attachment object in Ivanti',
    },
];
const getOperation = [
    {
        displayName: 'Record ID',
        name: 'id',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                operation: ['get'],
                resource: ['attachment'],
            },
        },
        routing: {
            send: {
                type: 'query',
                property: '$filter',
                value: "=RecId eq '{{ $value }}'",
            },
        },
        description: 'RecId value of the attachment object in Ivanti',
    },
    {
        displayName: 'Query Parameters',
        name: 'queryParameters',
        type: 'collection',
        placeholder: 'Extend Query',
        default: {},
        displayOptions: {
            show: {
                resource: ['attachment'],
                operation: ['get'],
            },
        },
        options: [
            {
                displayName: 'Select Fields',
                name: 'select',
                type: 'string',
                default: '',
                routing: {
                    send: {
                        type: 'query',
                        property: '$select',
                        value: '={{ $value !== "" ? $value : undefined }}',
                    },
                },
                description: 'Include only these fields',
                placeholder: 'RecId, CreatedDateTime, LastModDateTime',
            },
        ],
        description: 'Send additional query parameters. More <a href="https://www.odata.org/getting-started/basic-tutorial/#queryData">information</a>.',
    },
];
const getAllOperation = [
    {
        displayName: 'Limit',
        name: 'limit',
        type: 'number',
        default: 50,
        typeOptions: {
            minValue: 1,
            maxValue: 100,
        },
        displayOptions: {
            show: {
                resource: ['attachment'],
                operation: ['getAll'],
            },
        },
        routing: {
            send: {
                type: 'query',
                property: '$top',
                value: '={{ $value }}',
            },
        },
        description: 'Max number of results to return',
    },
    {
        displayName: 'Send Sort Parameters',
        name: 'sortOptions',
        type: 'boolean',
        displayOptions: {
            show: {
                resource: ['attachment'],
                operation: ['getAll'],
            },
        },
        default: false,
        description: 'Whether the request has sorting parameters or not',
    },
    {
        displayName: 'Sort',
        name: 'sortUi',
        type: 'fixedCollection',
        placeholder: 'Add Sort Options',
        displayOptions: {
            show: {
                resource: ['attachment'],
                operation: ['getAll'],
                sortOptions: [true],
            },
        },
        typeOptions: {
            multipleValues: false,
        },
        default: {},
        options: [
            {
                displayName: 'Sort Options',
                name: 'sortDetails',
                values: [
                    {
                        displayName: 'Sort Key Name or ID',
                        name: 'sortBy',
                        type: 'options',
                        options: [
                            {
                                name: 'Creation Time',
                                value: 'CreatedDateTime',
                            },
                            {
                                name: 'Last Modification Time',
                                value: 'LastModDateTime',
                            },
                        ],
                        description: 'Choose from the list, or specify an ID using an <a href="https://docs.n8n.io/code-examples/expressions/">expression</a>',
                        default: 'CreatedDateTime',
                    },
                    {
                        displayName: 'Sort Order',
                        name: 'orderBy',
                        type: 'options',
                        options: [
                            {
                                name: 'Ascending',
                                value: 'asc',
                            },
                            {
                                name: 'Descending',
                                value: 'desc',
                            },
                        ],
                        default: 'desc',
                        routing: {
                            send: {
                                type: 'query',
                                property: '$orderby',
                                value: '={{ $parent.sortBy }} {{ $value }}',
                            },
                        },
                    },
                ],
            },
        ],
    },
    {
        displayName: 'Query Parameters',
        name: 'queryParameters',
        type: 'collection',
        placeholder: 'Extend Query',
        default: {},
        displayOptions: {
            show: {
                resource: ['attachment'],
                operation: ['getAll'],
            },
        },
        options: [
            {
                displayName: 'Result Filter',
                name: 'filter',
                type: 'string',
                default: '',
                routing: {
                    send: {
                        type: 'query',
                        property: '$filter',
                        value: '={{ $value !== "" ? $value : undefined }}',
                    },
                },
                description: 'An expression which will filter the results',
                placeholder: "Status eq 'Open'",
            },
            {
                displayName: 'Select Fields',
                name: 'select',
                type: 'string',
                default: '',
                routing: {
                    send: {
                        type: 'query',
                        property: '$select',
                        value: '={{ $value !== "" ? $value : undefined }}',
                    },
                },
                description: 'Include only these fields',
                placeholder: 'RecId, CreatedDateTime, LastModDateTime',
            },
            {
                displayName: 'Skip Records',
                name: 'skip',
                type: 'number',
                default: 100,
                typeOptions: {
                    minValue: 1,
                    maxValue: 100,
                },
                routing: {
                    send: {
                        type: 'query',
                        property: '$skip',
                        value: '={{ $value !== "" ? $value : undefined }}',
                    },
                },
                description: 'Use this property when looping trough more than 100 results',
            },
        ],
        description: 'Send additional query parameters. More <a href="https://www.odata.org/getting-started/basic-tutorial/#queryData">information</a>.',
    },
];
const getCountOperation = [
    {
        displayName: 'Query Parameters',
        name: 'queryParameters',
        type: 'collection',
        placeholder: 'Extend Query',
        default: {},
        displayOptions: {
            show: {
                resource: ['attachment'],
                operation: ['getCount'],
            },
        },
        options: [
            {
                displayName: 'Result Filter',
                name: 'filter',
                type: 'string',
                default: '',
                routing: {
                    send: {
                        type: 'query',
                        property: '$filter',
                        value: '={{ $value !== "" ? $value : undefined }}',
                    },
                },
                description: 'An expression which will filter the results',
                placeholder: "Status eq 'Open'",
            },
        ],
        description: 'Send additional query parameters. More <a href="https://www.odata.org/getting-started/basic-tutorial/#queryData">information</a>.',
    },
];
const updateOperation = [
    {
        displayName: 'Record ID',
        name: 'id',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                operation: ['update'],
                resource: ['attachment'],
            },
        },
        routing: {
            request: {
                url: "=/{{$parameter['busenessObjectId']}}s('{{ $value }}')",
            },
        },
        description: 'RecId value of the attachment object in Ivanti',
    },
    {
        displayName: 'Send Custom Fields',
        name: 'attachmentFields',
        type: 'boolean',
        displayOptions: {
            show: {
                resource: ['attachment'],
                operation: ['update'],
            },
        },
        default: true,
        description: 'Whether creating object requires more attachment prameters',
    },
    {
        displayName: 'Custom Fields',
        name: 'attachmentProperties',
        type: 'fixedCollection',
        displayOptions: {
            show: {
                resource: ['attachment'],
                operation: ['update'],
                attachmentFields: [true],
            },
        },
        default: {
            property: [
                {
                    name: '',
                    value: '',
                },
            ],
        },
        placeholder: 'Add Custom Field',
        typeOptions: {
            multipleValues: true,
        },
        options: [
            {
                name: 'property',
                displayName: 'Custom Field',
                values: [
                    {
                        displayName: 'Field Name or ID',
                        name: 'name',
                        type: 'string',
                        required: true,
                        default: '',
                        description: 'Name of the attachment field to set',
                    },
                    {
                        displayName: 'Field Value',
                        name: 'value',
                        type: 'string',
                        required: true,
                        default: '',
                        routing: {
                            send: {
                                type: 'body',
                                property: '={{ $parent.name !== " " ? $parent.name : undefined}}',
                                value: '={{ $value !== " " ? $value : undefined }}',
                            },
                        },
                        description: 'Value to set on the attachment field',
                    },
                ],
            },
        ],
    },
];
exports.attachmentFields = [
    ...createOperation,
    ...deleteOperation,
    ...getAllOperation,
    ...getCountOperation,
    ...getOperation,
    ...updateOperation,
];
//# sourceMappingURL=AttachmentDescription.js.map