"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.customFields = exports.customOperations = void 0;
exports.customOperations = [
    {
        displayName: 'Business Object Name',
        name: 'busenessObjectId',
        required: true,
        noDataExpression: true,
        type: 'string',
        default: '',
        displayOptions: {
            show: {
                resource: ['custom'],
            },
        },
    },
    {
        displayName: 'Operation',
        name: 'operation',
        type: 'options',
        noDataExpression: true,
        displayOptions: {
            show: {
                resource: ['custom'],
            },
        },
        options: [
            {
                name: 'Create',
                value: 'create',
                description: 'Create a custom object',
                action: 'Create a custom object',
                routing: {
                    request: {
                        method: 'POST',
                        url: '=/{{$parameter["busenessObjectId"]}}s',
                    },
                },
            },
            {
                name: 'Delete',
                value: 'delete',
                description: 'Delete a custom object',
                action: 'Delete a custom object',
                routing: {
                    request: {
                        method: 'DELETE',
                    },
                },
            },
            {
                name: 'Get',
                value: 'get',
                description: 'Retrieve a custom object',
                action: 'Get a custom object',
                routing: {
                    request: {
                        method: 'GET',
                        url: '=/{{$parameter["busenessObjectId"]}}s',
                    },
                    output: {
                        postReceive: [
                            {
                                type: 'rootProperty',
                                properties: {
                                    property: 'value',
                                },
                            },
                        ],
                    },
                },
            },
            {
                name: 'Get Count',
                value: 'getCount',
                description: 'Retrieve a count of custom objects',
                action: 'Retrieve a count of custom objects',
                routing: {
                    request: {
                        method: 'GET',
                        url: '=/{{$parameter["busenessObjectId"]}}s',
                    },
                    send: {
                        type: 'query',
                        property: '$top',
                        value: '1',
                    },
                    output: {
                        postReceive: [
                            {
                                type: 'setKeyValue',
                                properties: {
                                    count: '={{$responseItem["@odata.count"] == 0 ? 1 : $responseItem["@odata.count"] }}',
                                },
                            },
                        ],
                    },
                },
            },
            {
                name: 'Get Many',
                value: 'getAll',
                description: 'Get many custom objects',
                action: 'Get many custom objects',
                routing: {
                    request: {
                        method: 'GET',
                        url: '=/{{$parameter["busenessObjectId"]}}s',
                    },
                    output: {
                        postReceive: [
                            {
                                type: 'rootProperty',
                                properties: {
                                    property: 'value',
                                },
                            },
                        ],
                    },
                },
            },
            {
                name: 'Link',
                value: 'link',
                description: 'Link a custom object',
                action: 'Link a custom object',
                routing: {
                    request: {
                        method: 'PATCH',
                    },
                },
            },
            {
                name: 'Update',
                value: 'update',
                description: 'Update a custom object',
                action: 'Update a custom object',
                routing: {
                    request: {
                        method: 'PATCH',
                    },
                },
            },
        ],
        default: 'getAll',
    },
];
const createOperation = [
    {
        displayName: 'Send Custom Fields',
        name: 'customFields',
        type: 'boolean',
        displayOptions: {
            show: {
                resource: ['custom'],
                operation: ['create'],
            },
        },
        default: true,
        description: 'Whether creating object requires more custom prameters',
    },
    {
        displayName: 'Custom Fields',
        name: 'customProperties',
        type: 'fixedCollection',
        displayOptions: {
            show: {
                resource: ['custom'],
                operation: ['create'],
                customFields: [true],
            },
        },
        default: {
            property: [
                {
                    name: '',
                    value: '',
                },
            ],
        },
        placeholder: 'Add Custom Field',
        typeOptions: {
            multipleValues: true,
        },
        options: [
            {
                name: 'property',
                displayName: 'Custom Field',
                values: [
                    {
                        displayName: 'Field Name or ID',
                        name: 'name',
                        type: 'string',
                        required: true,
                        default: '',
                        description: 'Name of the custom field to set',
                    },
                    {
                        displayName: 'Field Value',
                        name: 'value',
                        type: 'string',
                        required: true,
                        default: '',
                        routing: {
                            send: {
                                type: 'body',
                                property: '={{$parent.name}}',
                                value: '={{ $value !== " " ? $value : undefined }}',
                            },
                        },
                        description: 'Value to set on the custom field',
                    },
                ],
            },
        ],
    },
];
const deleteOperation = [
    {
        displayName: 'Record ID',
        name: 'id',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                operation: ['delete'],
                resource: ['custom'],
            },
        },
        routing: {
            request: {
                url: "=/{{$parameter['busenessObjectId']}}s('{{ $value }}')",
            },
            output: {
                postReceive: [
                    {
                        type: 'setKeyValue',
                        properties: {
                            Result: 'Success',
                        },
                    },
                ],
            },
        },
        description: 'RecId value of the custom object in Ivanti',
    },
];
const getOperation = [
    {
        displayName: 'Record ID',
        name: 'id',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                operation: ['get'],
                resource: ['custom'],
            },
        },
        routing: {
            send: {
                type: 'query',
                property: '$filter',
                value: "=RecId eq '{{ $value }}'",
            },
        },
        description: 'RecId value of the custom object in Ivanti',
    },
    {
        displayName: 'Query Parameters',
        name: 'queryParameters',
        type: 'collection',
        placeholder: 'Extend Query',
        default: {},
        displayOptions: {
            show: {
                resource: ['custom'],
                operation: ['get'],
            },
        },
        options: [
            {
                displayName: 'Select Fields',
                name: 'select',
                type: 'string',
                default: '',
                routing: {
                    send: {
                        type: 'query',
                        property: '$select',
                        value: '={{ $value !== "" ? $value : undefined }}',
                    },
                },
                description: 'Include only these fields',
                placeholder: 'RecId, CreatedDateTime, LastModDateTime',
            },
        ],
        description: 'Send additional query parameters. More <a href="https://www.odata.org/getting-started/basic-tutorial/#queryData">information</a>.',
    },
];
const getAllOperation = [
    {
        displayName: 'Limit',
        name: 'limit',
        type: 'number',
        default: 50,
        typeOptions: {
            minValue: 1,
            maxValue: 100,
        },
        displayOptions: {
            show: {
                resource: ['custom'],
                operation: ['getAll'],
            },
        },
        routing: {
            send: {
                type: 'query',
                property: '$top',
                value: '={{ $value }}',
            },
        },
        description: 'Max number of results to return',
    },
    {
        displayName: 'Send Sort Parameters',
        name: 'sortOptions',
        type: 'boolean',
        displayOptions: {
            show: {
                resource: ['custom'],
                operation: ['getAll'],
            },
        },
        default: false,
        description: 'Whether the request has sorting parameters or not',
    },
    {
        displayName: 'Sort',
        name: 'sortUi',
        type: 'fixedCollection',
        placeholder: 'Add Sort Options',
        displayOptions: {
            show: {
                resource: ['custom'],
                operation: ['getAll'],
                sortOptions: [true],
            },
        },
        typeOptions: {
            multipleValues: false,
        },
        default: {},
        options: [
            {
                displayName: 'Sort Options',
                name: 'sortDetails',
                values: [
                    {
                        displayName: 'Sort Key Name or ID',
                        name: 'sortBy',
                        type: 'options',
                        options: [
                            {
                                name: 'Creation Time',
                                value: 'CreatedDateTime',
                            },
                            {
                                name: 'Last Modification Time',
                                value: 'LastModDateTime',
                            },
                        ],
                        description: 'Choose from the list, or specify an ID using an <a href="https://docs.n8n.io/code-examples/expressions/">expression</a>',
                        default: 'CreatedDateTime',
                    },
                    {
                        displayName: 'Sort Order',
                        name: 'orderBy',
                        type: 'options',
                        options: [
                            {
                                name: 'Ascending',
                                value: 'asc',
                            },
                            {
                                name: 'Descending',
                                value: 'desc',
                            },
                        ],
                        default: 'desc',
                        routing: {
                            send: {
                                type: 'query',
                                property: '$orderby',
                                value: '={{ $parent.sortBy }} {{ $value }}',
                            },
                        },
                    },
                ],
            },
        ],
    },
    {
        displayName: 'Query Parameters',
        name: 'queryParameters',
        type: 'collection',
        placeholder: 'Extend Query',
        default: {},
        displayOptions: {
            show: {
                resource: ['custom'],
                operation: ['getAll'],
            },
        },
        options: [
            {
                displayName: 'Result Filter',
                name: 'filter',
                type: 'string',
                default: '',
                routing: {
                    send: {
                        type: 'query',
                        property: '$filter',
                        value: '={{ $value !== "" ? $value : undefined }}',
                    },
                },
                description: 'An expression which will filter the results',
                placeholder: "Status eq 'Open'",
            },
            {
                displayName: 'Select Fields',
                name: 'select',
                type: 'string',
                default: '',
                routing: {
                    send: {
                        type: 'query',
                        property: '$select',
                        value: '={{ $value !== "" ? $value : undefined }}',
                    },
                },
                description: 'Include only these fields',
                placeholder: 'RecId, CreatedDateTime, LastModDateTime',
            },
            {
                displayName: 'Skip Records',
                name: 'skip',
                type: 'number',
                default: 100,
                typeOptions: {
                    minValue: 1,
                    maxValue: 100,
                },
                routing: {
                    send: {
                        type: 'query',
                        property: '$skip',
                        value: '={{ $value !== "" ? $value : undefined }}',
                    },
                },
                description: 'Use this property when looping trough more than 100 results',
            },
        ],
        description: 'Send additional query parameters. More <a href="https://www.odata.org/getting-started/basic-tutorial/#queryData">information</a>.',
    },
];
const getCountOperation = [
    {
        displayName: 'Query Parameters',
        name: 'queryParameters',
        type: 'collection',
        placeholder: 'Extend Query',
        default: {},
        displayOptions: {
            show: {
                resource: ['custom'],
                operation: ['getCount'],
            },
        },
        options: [
            {
                displayName: 'Result Filter',
                name: 'filter',
                type: 'string',
                default: '',
                routing: {
                    send: {
                        type: 'query',
                        property: '$filter',
                        value: '={{ $value !== "" ? $value : undefined }}',
                    },
                },
                description: 'An expression which will filter the results',
                placeholder: "Status eq 'Open'",
            },
        ],
        description: 'Send additional query parameters. More <a href="https://www.odata.org/getting-started/basic-tutorial/#queryData">information</a>.',
    },
];
const updateOperation = [
    {
        displayName: 'Record ID',
        name: 'id',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                operation: ['update'],
                resource: ['custom'],
            },
        },
        routing: {
            request: {
                url: "=/{{$parameter['busenessObjectId']}}s('{{ $value }}')",
            },
        },
        description: 'RecId value of the custom object in Ivanti',
    },
    {
        displayName: 'Send Custom Fields',
        name: 'customFields',
        type: 'boolean',
        displayOptions: {
            show: {
                resource: ['custom'],
                operation: ['update'],
            },
        },
        default: true,
        description: 'Whether creating object requires more custom prameters',
    },
    {
        displayName: 'Custom Fields',
        name: 'customProperties',
        type: 'fixedCollection',
        displayOptions: {
            show: {
                resource: ['custom'],
                operation: ['update'],
                customFields: [true],
            },
        },
        default: {
            property: [
                {
                    name: '',
                    value: '',
                },
            ],
        },
        placeholder: 'Add Custom Field',
        typeOptions: {
            multipleValues: true,
        },
        options: [
            {
                name: 'property',
                displayName: 'Custom Field',
                values: [
                    {
                        displayName: 'Field Name or ID',
                        name: 'name',
                        type: 'string',
                        required: true,
                        default: '',
                        description: 'Name of the custom field to set',
                    },
                    {
                        displayName: 'Field Value',
                        name: 'value',
                        type: 'string',
                        required: true,
                        default: '',
                        routing: {
                            send: {
                                type: 'body',
                                property: '={{ $parent.name !== " " ? $parent.name : undefined}}',
                                value: '={{ $value !== " " ? $value : undefined }}',
                            },
                        },
                        description: 'Value to set on the custom field',
                    },
                ],
            },
        ],
    },
];
const linkOperation = [
    {
        displayName: "Record ID (This Object)",
        name: 'id',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                operation: ['link'],
                resource: ['custom'],
            },
        },
        description: 'RecId value of the custom object in Ivanti',
    },
    {
        displayName: 'Relationship Name',
        name: 'relName',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                operation: ['link'],
                resource: ['custom'],
            },
        },
        description: 'Relationship name which will be used to link business objects',
    },
    {
        displayName: 'Record ID (Related Object)',
        name: 'rid',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                operation: ['link'],
                resource: ['custom'],
            },
        },
        routing: {
            request: {
                url: "=/{{ $parameter['busenessObjectId'] }}s('{{ $parameter['id'] }}')/{{ $parameter['relName'] }}('{{ $value }}')/$Ref",
            },
        },
        description: 'RecId value of the related business object in Ivanti',
    },
];
exports.customFields = [
    ...createOperation,
    ...deleteOperation,
    ...getAllOperation,
    ...getCountOperation,
    ...getOperation,
    ...updateOperation,
    ...linkOperation,
];
//# sourceMappingURL=CustomDescription.js.map