"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Ivanti = void 0;
const EventDescription_1 = require("./EventDescription");
const TaskDescription_1 = require("./TaskDescription");
const CustomDescription_1 = require("./CustomDescription");
const ChangeDescription_1 = require("./ChangeDescription");
const EmployeeDescription_1 = require("./EmployeeDescription");
const IncidentDescription_1 = require("./IncidentDescription");
class Ivanti {
    constructor() {
        this.description = {
            displayName: 'Ivanti',
            name: 'Ivanti',
            icon: 'file:ivanti.svg',
            group: ['transform'],
            version: 1,
            subtitle: '={{$parameter["operation"] + ": " + $parameter["resource"]}}',
            description: 'Interact with Ivanti API',
            defaults: {
                name: 'Ivanti',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [
                {
                    name: 'IvantiApi',
                    required: true,
                },
            ],
            requestDefaults: {
                skipSslCertificateValidation: true,
                returnFullResponse: true,
                baseURL: '={{ $credentials.baseUrl.replace(new RegExp("/$"), "") }}/HEAT/api/odata/businessobject',
                url: '',
                headers: {
                    Accept: 'application/json',
                    'Content-Type': 'application/json',
                },
            },
            properties: [
                {
                    displayName: 'Resource',
                    name: 'resource',
                    type: 'options',
                    noDataExpression: true,
                    options: [
                        {
                            name: 'Change',
                            value: 'change',
                        },
                        {
                            name: 'Custom Business Object',
                            value: 'custom',
                        },
                        {
                            name: 'Employee',
                            value: 'employee',
                        },
                        {
                            name: 'Event',
                            value: 'event',
                        },
                        {
                            name: 'Incident',
                            value: 'incident',
                        },
                        {
                            name: 'Task',
                            value: 'task',
                        },
                    ],
                    default: 'event',
                },
                ...EventDescription_1.eventOperations,
                ...EventDescription_1.eventFields,
                ...TaskDescription_1.taskOperations,
                ...TaskDescription_1.taskFields,
                ...CustomDescription_1.customOperations,
                ...CustomDescription_1.customFields,
                ...ChangeDescription_1.changeOperations,
                ...ChangeDescription_1.changeFields,
                ...EmployeeDescription_1.employeeOperations,
                ...EmployeeDescription_1.employeeFields,
                ...IncidentDescription_1.incidentOperations,
                ...IncidentDescription_1.incidentFields,
            ],
        };
    }
}
exports.Ivanti = Ivanti;
//# sourceMappingURL=Ivanti.node.js.map